==> cbang_0.0.0.tar.gz: cbang-1.3.2/src/cbang/event/HTTPSessionHandler.cpp <==
/******************************************************************************\

          This file is part of the C! library.  A.K.A the cbang library.

                Copyright (c) 2003-2019, Cauldron Development LLC
                   Copyright (c) 2003-2017, Stanford University
                               All rights reserved.

         The C! library is free software: you can redistribute it and/or
        modify it under the terms of the GNU Lesser General Public License
       as published by the Free Software Foundation, either version 2.1 of
               the License, or (at your option) any later version.

        The C! library is distributed in the hope that it will be useful,
          but WITHOUT ANY WARRANTY; without even the implied warranty of
        MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
                 Lesser General Public License for more details.

         You should have received a copy of the GNU Lesser General Public
                 License along with the C! library.  If not, see
                         <http://www.gnu.org/licenses/>.

        In addition, BSD licensing may be granted on a case by case basis
        by written permission from at least one of the copyright holders.
           You may request written permission by emailing the authors.

                  For information regarding this software email:
                                 Joseph Coffland
                          joseph@cauldrondevelopment.com

\******************************************************************************/

#include "HTTPSessionHandler.h"

#include "Request.h"

#include <cbang/net/SessionManager.h>
#include <cbang/log/Logger.h>

using namespace std;
using namespace cb::Event;


bool HTTPSessionHandler::operator()(Request &req) {
  // Check if Session is already loaded
  if (!req.getSession().isNull()) return false;

  // Get session ID
  string sid = req.getSessionID(sessionManager->getSessionCookie(), header);
  if (sid.empty()) return false;

  // Get session
  try {
    req.setSession(sessionManager->lookupSession(sid));
  } catch (const Exception &) {return false;}

  return false;
}

==> cbang-1.6.0.tar.gz: cbang-1.6.0/src/cbang/event/HTTPSessionHandler.cpp <==
/******************************************************************************\

          This file is part of the C! library.  A.K.A the cbang library.

                Copyright (c) 2003-2019, Cauldron Development LLC
                   Copyright (c) 2003-2017, Stanford University
                               All rights reserved.

         The C! library is free software: you can redistribute it and/or
        modify it under the terms of the GNU Lesser General Public License
       as published by the Free Software Foundation, either version 2.1 of
               the License, or (at your option) any later version.

        The C! library is distributed in the hope that it will be useful,
          but WITHOUT ANY WARRANTY; without even the implied warranty of
        MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
                 Lesser General Public License for more details.

         You should have received a copy of the GNU Lesser General Public
                 License along with the C! library.  If not, see
                         <http://www.gnu.org/licenses/>.

        In addition, BSD licensing may be granted on a case by case basis
        by written permission from at least one of the copyright holders.
           You may request written permission by emailing the authors.

                  For information regarding this software email:
                                 Joseph Coffland
                          joseph@cauldrondevelopment.com

\******************************************************************************/

#include "HTTPSessionHandler.h"

#include "Request.h"

#include <cbang/net/SessionManager.h>
#include <cbang/log/Logger.h>

using namespace std;
using namespace cb::Event;


bool HTTPSessionHandler::operator()(Request &req) {
  // Check if Session is already loaded
  if (req.getSession().isSet()) return false;

  // Get session ID
  const string &cookie = sessionManager->getSessionCookie();
  string sid = req.getSessionID(cookie, header);
  LOG_DEBUG(4, "Client " << req.getClientIP() << " sid=" << sid
            << " cookie=" << cookie << " header=" << header);
  if (sid.empty()) return false;

  // Get session
  try {
    req.setSession(sessionManager->lookupSession(sid));
  } catch (const Exception &) {}

  return false;
}
